USAGE:

    easysetc.exe [-allparameter] [--help |--i | --version |

                                 --execute [CMD] |

                                --firmware xxx.bin|

								--com [COM number]|

								--sn [Serial number]

Options:

    --help      show help information.

    --i			show device information.

    --version   show software version NO.

    --execute   Issue instruction followed by instruction.

    --firmware  Firmware upgrade command followed by firmware file path.

    --xml		Download configuration file

    --savexml	Save to configuration file

    --com		Serial port NO

    --sn		Serial number NO

    --name		Device name

Exameple:

    easysetc.exe --help							show help information.

    easysetc.exe --version						show software version NO.

    easysetc.exe --execute RRDDUR2000			Set the reading timeout.

    easysetc.exe --execute RRDDUR2000 --com		17 Specify the serial port NO to set the reading timeout.

    easysetc.exe --execute RRDDUR2000 --sn	12345 Specify the serial number NO to set the reading timeout.

    easysetc.exe --execute RRDDUR2000 --name xx Specify Device name to set the reading timeout.

    easysetc.exe --firmware xxx.bin				Upgrade the hardware.

    easysetc.exe --firmware xxx.bin --com 17 	Specify the serial port NO to upgrade the hardware.

    easysetc.exe --firmware xxx.bin --sn 12345  Specify the serial number NO to upgrade the hardware.

    easysetc.exe --firmware xxx.bin --name xx  Specify Device name to upgrade the hardware.

    easysetc.exe --firmware xxx.bin --version xx  Verify Device firmware version.

    easysetc.exe --xml xxx.xml					Download configuration file.

    easysetc.exe --xml xxx.xml --com 17			Specify the serial port NO to download configuration file.

    easysetc.exe --xml xxx.xml --sn 12345		Specify the serial number NO to download configuration file.

    easysetc.exe --xml xxx.xml --name xx		Specify Device name to download configuration file.

    easysetc.exe --savexml						Save to configuration file.

    easysetc.exe --savexml --com 17				Specify the serial port NO to save to configuration file.

    easysetc.exe --savexml --sn 12345			Specify the serial number NO to save to configuration file.

    easysetc.exe --savexml --name xx			Specify Device name to save to configuration file.

    easysetc.exe --send SCNMOD2 --name xx		Specify Device name to send command.

